Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareType(J.api, "JmolAdapterStructureIterator", null);
})();
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
